@@ -1,10 +1,20 @@
+"""veh http://www.uif.shcp.gob.mx/recepcion/veh"""
 from decimal import Decimal
 from datetime import datetime, date, time
 from collections.abc import Sequence
-from ...cfdi import CFDI, XElement
+from ... import CFDI, XElement, ScalarMap
 
 
-class DatosLiquidacionType(XElement):
+class DatosLiquidacionType(ScalarMap):
+    """
+    
+    :param fecha_pago:
+    :param forma_pago:
+    :param moneda:
+    :param monto_operacion:
+    :param instrumento_monetario:
+    """
+    
     def __init__(
             self,
             fecha_pago: date,
@@ -13,15 +23,6 @@ class DatosLiquidacionType(XElement):
             monto_operacion: str,
             instrumento_monetario: str = None,
     ): 
-        """
-        
-        :param fecha_pago:
-        :param forma_pago:
-        :param moneda:
-        :param monto_operacion:
-        :param instrumento_monetario:
-        """
-        
         super().__init__({
             'FechaPago': fecha_pago,
             'FormaPago': forma_pago,
@@ -31,7 +32,18 @@ class DatosLiquidacionType(XElement):
         })
         
 
-class DatosVehiculoAereoType(XElement):
+class DatosVehiculoAereoType(ScalarMap):
+    """
+    
+    :param marca_fabricante:
+    :param modelo:
+    :param anio:
+    :param numero_serie:
+    :param nivel_blindaje:
+    :param bandera:
+    :param matricula:
+    """
+    
     def __init__(
             self,
             marca_fabricante: str,
@@ -42,17 +54,6 @@ class DatosVehiculoAereoType(XElement):
             bandera: str = None,
             matricula: str = None,
     ): 
-        """
-        
-        :param marca_fabricante:
-        :param modelo:
-        :param anio:
-        :param numero_serie:
-        :param nivel_blindaje:
-        :param bandera:
-        :param matricula:
-        """
-        
         super().__init__({
             'MarcaFabricante': marca_fabricante,
             'Modelo': modelo,
@@ -64,7 +65,18 @@ class DatosVehiculoAereoType(XElement):
         })
         
 
-class DatosVehiculoMaritimoType(XElement):
+class DatosVehiculoMaritimoType(ScalarMap):
+    """
+    
+    :param marca_fabricante:
+    :param modelo:
+    :param anio:
+    :param numero_serie:
+    :param nivel_blindaje:
+    :param bandera:
+    :param matricula:
+    """
+    
     def __init__(
             self,
             marca_fabricante: str,
@@ -75,17 +87,6 @@ class DatosVehiculoMaritimoType(XElement):
             bandera: str = None,
             matricula: str = None,
     ): 
-        """
-        
-        :param marca_fabricante:
-        :param modelo:
-        :param anio:
-        :param numero_serie:
-        :param nivel_blindaje:
-        :param bandera:
-        :param matricula:
-        """
-        
         super().__init__({
             'MarcaFabricante': marca_fabricante,
             'Modelo': modelo,
@@ -97,7 +98,18 @@ class DatosVehiculoMaritimoType(XElement):
         })
         
 
-class DatosVehiculoTerrestreType(XElement):
+class DatosVehiculoTerrestreType(ScalarMap):
+    """
+    
+    :param marca_fabricante:
+    :param modelo:
+    :param anio:
+    :param nivel_blindaje:
+    :param vin:
+    :param repuve:
+    :param placas:
+    """
+    
     def __init__(
             self,
             marca_fabricante: str,
@@ -108,17 +120,6 @@ class DatosVehiculoTerrestreType(XElement):
             repuve: str = None,
             placas: str = None,
     ): 
-        """
-        
-        :param marca_fabricante:
-        :param modelo:
-        :param anio:
-        :param nivel_blindaje:
-        :param vin:
-        :param repuve:
-        :param placas:
-        """
-        
         super().__init__({
             'MarcaFabricante': marca_fabricante,
             'Modelo': modelo,
@@ -130,20 +131,20 @@ class DatosVehiculoTerrestreType(XElement):
         })
         
 
-class TipoVehiculoType(XElement):
+class TipoVehiculoType(ScalarMap):
+    """
+    
+    :param datos_vehiculo_terrestre:
+    :param datos_vehiculo_maritimo:
+    :param datos_vehiculo_aereo:
+    """
+    
     def __init__(
             self,
             datos_vehiculo_terrestre: DatosVehiculoTerrestreType | dict = None,
             datos_vehiculo_maritimo: DatosVehiculoMaritimoType | dict = None,
             datos_vehiculo_aereo: DatosVehiculoAereoType | dict = None,
     ): 
-        """
-        
-        :param datos_vehiculo_terrestre:
-        :param datos_vehiculo_maritimo:
-        :param datos_vehiculo_aereo:
-        """
-        
         super().__init__({
             'DatosVehiculoTerrestre': datos_vehiculo_terrestre,
             'DatosVehiculoMaritimo': datos_vehiculo_maritimo,
@@ -151,7 +152,16 @@ class TipoVehiculoType(XElement):
         })
         
 
-class DatosOperacionType(XElement):
+class DatosOperacionType(ScalarMap):
+    """
+    
+    :param fecha_operacion:
+    :param codigo_postal:
+    :param tipo_operacion:
+    :param tipo_vehiculo:
+    :param datos_liquidacion:
+    """
+    
     def __init__(
             self,
             fecha_operacion: date,
@@ -160,15 +170,6 @@ class DatosOperacionType(XElement):
             tipo_vehiculo: TipoVehiculoType | dict | Sequence[TipoVehiculoType | dict],
             datos_liquidacion: DatosLiquidacionType | dict | Sequence[DatosLiquidacionType | dict] = None,
     ): 
-        """
-        
-        :param fecha_operacion:
-        :param codigo_postal:
-        :param tipo_operacion:
-        :param tipo_vehiculo:
-        :param datos_liquidacion:
-        """
-        
         super().__init__({
             'FechaOperacion': fecha_operacion,
             'CodigoPostal': codigo_postal,
@@ -178,35 +179,35 @@ class DatosOperacionType(XElement):
         })
         
 
-class DetalleOperacionesType(XElement):
+class DetalleOperacionesType(ScalarMap):
+    """
+    
+    :param datos_operacion:
+    """
+    
     def __init__(
             self,
             datos_operacion: DatosOperacionType | dict | Sequence[DatosOperacionType | dict],
     ): 
-        """
-        
-        :param datos_operacion:
-        """
-        
         super().__init__({
             'DatosOperacion': datos_operacion,
         })
         
 
-class FideicomisoSimpleType(XElement):
+class FideicomisoSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'Rfc': rfc,
@@ -214,7 +215,15 @@ class FideicomisoSimpleType(XElement):
         })
         
 
-class PersonaMoralSimpleType(XElement):
+class PersonaMoralSimpleType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param fecha_constitucion:
+    :param rfc:
+    :param pais_nacionalidad:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -222,14 +231,6 @@ class PersonaMoralSimpleType(XElement):
             rfc: str = None,
             pais_nacionalidad: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param fecha_constitucion:
-        :param rfc:
-        :param pais_nacionalidad:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'FechaConstitucion': fecha_constitucion,
@@ -238,7 +239,18 @@ class PersonaMoralSimpleType(XElement):
         })
         
 
-class PersonaFisicaSimpleType(XElement):
+class PersonaFisicaSimpleType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    :param pais_nacionalidad:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -249,17 +261,6 @@ class PersonaFisicaSimpleType(XElement):
             curp: str = None,
             pais_nacionalidad: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        :param pais_nacionalidad:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -271,20 +272,20 @@ class PersonaFisicaSimpleType(XElement):
         })
         
 
-class TipoPersonaSimpleType(XElement):
+class TipoPersonaSimpleType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaSimpleType | dict = None,
             persona_moral: PersonaMoralSimpleType | dict = None,
             fideicomiso: FideicomisoSimpleType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -292,35 +293,35 @@ class TipoPersonaSimpleType(XElement):
         })
         
 
-class DuenoBeneficiarioType(XElement):
+class DuenoBeneficiarioType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaSimpleType | dict,
     ): 
-        """
-        
-        :param tipo_persona:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
         })
         
 
-class TelefonoType(XElement):
+class TelefonoType(ScalarMap):
+    """
+    
+    :param clave_pais:
+    :param numero_telefono:
+    :param correo_electronico:
+    """
+    
     def __init__(
             self,
             clave_pais: str = None,
             numero_telefono: str = None,
             correo_electronico: str = None,
     ): 
-        """
-        
-        :param clave_pais:
-        :param numero_telefono:
-        :param correo_electronico:
-        """
-        
         super().__init__({
             'ClavePais': clave_pais,
             'NumeroTelefono': numero_telefono,
@@ -328,7 +329,19 @@ class TelefonoType(XElement):
         })
         
 
-class ExtranjeroType(XElement):
+class ExtranjeroType(ScalarMap):
+    """
+    
+    :param pais:
+    :param estado_provincia:
+    :param ciudad_poblacion:
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             pais: str,
@@ -340,18 +353,6 @@ class ExtranjeroType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param pais:
-        :param estado_provincia:
-        :param ciudad_poblacion:
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Pais': pais,
             'EstadoProvincia': estado_provincia,
@@ -364,7 +365,16 @@ class ExtranjeroType(XElement):
         })
         
 
-class NacionalType(XElement):
+class NacionalType(ScalarMap):
+    """
+    
+    :param colonia:
+    :param calle:
+    :param numero_exterior:
+    :param codigo_postal:
+    :param numero_interior:
+    """
+    
     def __init__(
             self,
             colonia: str,
@@ -373,15 +383,6 @@ class NacionalType(XElement):
             codigo_postal: str,
             numero_interior: str = None,
     ): 
-        """
-        
-        :param colonia:
-        :param calle:
-        :param numero_exterior:
-        :param codigo_postal:
-        :param numero_interior:
-        """
-        
         super().__init__({
             'Colonia': colonia,
             'Calle': calle,
@@ -391,25 +392,35 @@ class NacionalType(XElement):
         })
         
 
-class TipoDomicilioType(XElement):
+class TipoDomicilioType(ScalarMap):
+    """
+    
+    :param nacional:
+    :param extranjero:
+    """
+    
     def __init__(
             self,
             nacional: NacionalType | dict = None,
             extranjero: ExtranjeroType | dict = None,
     ): 
-        """
-        
-        :param nacional:
-        :param extranjero:
-        """
-        
         super().__init__({
             'Nacional': nacional,
             'Extranjero': extranjero,
         })
         
 
-class RepresentanteApoderadoType(XElement):
+class RepresentanteApoderadoType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -419,16 +430,6 @@ class RepresentanteApoderadoType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -439,7 +440,15 @@ class RepresentanteApoderadoType(XElement):
         })
         
 
-class FideicomisoType(XElement):
+class FideicomisoType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param apoderado_delegado:
+    :param rfc:
+    :param identificador_fideicomiso:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -447,14 +456,6 @@ class FideicomisoType(XElement):
             rfc: str = None,
             identificador_fideicomiso: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param apoderado_delegado:
-        :param rfc:
-        :param identificador_fideicomiso:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'ApoderadoDelegado': apoderado_delegado,
@@ -463,7 +464,17 @@ class FideicomisoType(XElement):
         })
         
 
-class PersonaMoralType(XElement):
+class PersonaMoralType(ScalarMap):
+    """
+    
+    :param denominacion_razon:
+    :param pais_nacionalidad:
+    :param giro_mercantil:
+    :param representante_apoderado:
+    :param fecha_constitucion:
+    :param rfc:
+    """
+    
     def __init__(
             self,
             denominacion_razon: str,
@@ -473,16 +484,6 @@ class PersonaMoralType(XElement):
             fecha_constitucion: date = None,
             rfc: str = None,
     ): 
-        """
-        
-        :param denominacion_razon:
-        :param pais_nacionalidad:
-        :param giro_mercantil:
-        :param representante_apoderado:
-        :param fecha_constitucion:
-        :param rfc:
-        """
-        
         super().__init__({
             'DenominacionRazon': denominacion_razon,
             'PaisNacionalidad': pais_nacionalidad,
@@ -493,7 +494,19 @@ class PersonaMoralType(XElement):
         })
         
 
-class PersonaFisicaType(XElement):
+class PersonaFisicaType(ScalarMap):
+    """
+    
+    :param nombre:
+    :param apellido_paterno:
+    :param apellido_materno:
+    :param pais_nacionalidad:
+    :param actividad_economica:
+    :param fecha_nacimiento:
+    :param rfc:
+    :param curp:
+    """
+    
     def __init__(
             self,
             nombre: str,
@@ -505,18 +518,6 @@ class PersonaFisicaType(XElement):
             rfc: str = None,
             curp: str = None,
     ): 
-        """
-        
-        :param nombre:
-        :param apellido_paterno:
-        :param apellido_materno:
-        :param pais_nacionalidad:
-        :param actividad_economica:
-        :param fecha_nacimiento:
-        :param rfc:
-        :param curp:
-        """
-        
         super().__init__({
             'Nombre': nombre,
             'ApellidoPaterno': apellido_paterno,
@@ -529,20 +530,20 @@ class PersonaFisicaType(XElement):
         })
         
 
-class TipoPersonaType(XElement):
+class TipoPersonaType(ScalarMap):
+    """
+    
+    :param persona_fisica:
+    :param persona_moral:
+    :param fideicomiso:
+    """
+    
     def __init__(
             self,
             persona_fisica: PersonaFisicaType | dict = None,
             persona_moral: PersonaMoralType | dict = None,
             fideicomiso: FideicomisoType | dict = None,
     ): 
-        """
-        
-        :param persona_fisica:
-        :param persona_moral:
-        :param fideicomiso:
-        """
-        
         super().__init__({
             'PersonaFisica': persona_fisica,
             'PersonaMoral': persona_moral,
@@ -550,20 +551,20 @@ class TipoPersonaType(XElement):
         })
         
 
-class PersonaAvisoType(XElement):
+class PersonaAvisoType(ScalarMap):
+    """
+    
+    :param tipo_persona:
+    :param tipo_domicilio:
+    :param telefono:
+    """
+    
     def __init__(
             self,
             tipo_persona: TipoPersonaType | dict,
             tipo_domicilio: TipoDomicilioType | dict = None,
             telefono: TelefonoType | dict = None,
     ): 
-        """
-        
-        :param tipo_persona:
-        :param tipo_domicilio:
-        :param telefono:
-        """
-        
         super().__init__({
             'TipoPersona': tipo_persona,
             'TipoDomicilio': tipo_domicilio,
@@ -571,43 +572,54 @@ class PersonaAvisoType(XElement):
         })
         
 
-class AlertaType(XElement):
+class AlertaType(ScalarMap):
+    """
+    
+    :param tipo_alerta:
+    :param descripcion_alerta:
+    """
+    
     def __init__(
             self,
             tipo_alerta: str,
             descripcion_alerta: str = None,
     ): 
-        """
-        
-        :param tipo_alerta:
-        :param descripcion_alerta:
-        """
-        
         super().__init__({
             'TipoAlerta': tipo_alerta,
             'DescripcionAlerta': descripcion_alerta,
         })
         
 
-class ModificatorioType(XElement):
+class ModificatorioType(ScalarMap):
+    """
+    
+    :param folio_modificacion:
+    :param descripcion_modificacion:
+    """
+    
     def __init__(
             self,
             folio_modificacion: str,
             descripcion_modificacion: str,
     ): 
-        """
-        
-        :param folio_modificacion:
-        :param descripcion_modificacion:
-        """
-        
         super().__init__({
             'FolioModificacion': folio_modificacion,
             'DescripcionModificacion': descripcion_modificacion,
         })
         
 
-class AvisoType(XElement):
+class AvisoType(ScalarMap):
+    """
+    
+    :param referencia_aviso:
+    :param prioridad:
+    :param alerta:
+    :param persona_aviso:
+    :param detalle_operaciones:
+    :param modificatorio:
+    :param dueno_beneficiario:
+    """
+    
     def __init__(
             self,
             referencia_aviso: str,
@@ -618,17 +630,6 @@ class AvisoType(XElement):
             modificatorio: ModificatorioType | dict = None,
             dueno_beneficiario: DuenoBeneficiarioType | dict | Sequence[DuenoBeneficiarioType | dict] = None,
     ): 
-        """
-        
-        :param referencia_aviso:
-        :param prioridad:
-        :param alerta:
-        :param persona_aviso:
-        :param detalle_operaciones:
-        :param modificatorio:
-        :param dueno_beneficiario:
-        """
-        
         super().__init__({
             'ReferenciaAviso': referencia_aviso,
             'Prioridad': prioridad,
@@ -640,7 +641,15 @@ class AvisoType(XElement):
         })
         
 
-class SujetoObligadoType(XElement):
+class SujetoObligadoType(ScalarMap):
+    """
+    
+    :param clave_sujeto_obligado:
+    :param clave_actividad:
+    :param clave_entidad_colegiada:
+    :param exento:
+    """
+    
     def __init__(
             self,
             clave_sujeto_obligado: str,
@@ -648,14 +657,6 @@ class SujetoObligadoType(XElement):
             clave_entidad_colegiada: str = None,
             exento: str = None,
     ): 
-        """
-        
-        :param clave_sujeto_obligado:
-        :param clave_actividad:
-        :param clave_entidad_colegiada:
-        :param exento:
-        """
-        
         super().__init__({
             'ClaveSujetoObligado': clave_sujeto_obligado,
             'ClaveActividad': clave_actividad,
@@ -664,20 +665,20 @@ class SujetoObligadoType(XElement):
         })
         
 
-class InformeType(XElement):
+class InformeType(ScalarMap):
+    """
+    
+    :param mes_reportado:
+    :param sujeto_obligado:
+    :param aviso:
+    """
+    
     def __init__(
             self,
             mes_reportado: str,
             sujeto_obligado: SujetoObligadoType | dict,
             aviso: AvisoType | dict | Sequence[AvisoType | dict] = None,
     ): 
-        """
-        
-        :param mes_reportado:
-        :param sujeto_obligado:
-        :param aviso:
-        """
-        
         super().__init__({
             'MesReportado': mes_reportado,
             'SujetoObligado': sujeto_obligado,
@@ -685,21 +686,21 @@ class InformeType(XElement):
         })
         
 
-class ArchivoType(XElement):
+class ArchivoType(ScalarMap):
+    """
+    
+    :param informe:
+    """
+    
     def __init__(
             self,
             informe: InformeType | dict | Sequence[InformeType | dict],
     ): 
-        """
-        
-        :param informe:
-        """
-        
         super().__init__({
             'Informe': informe,
         })
         
 
-class Archivo(ArchivoType):
+class Archivo(ArchivoType, XElement):
     tag = '{http://www.uif.shcp.gob.mx/recepcion/veh}archivo'
 
